/* eslint-disable @stencil/strict-boolean-conditions */
import { Component, Host, h, Prop, State } from '@stencil/core';
import { defaultIconPack } from '../../lib/icons';
import { useLanguage } from '../../lib/lang';
import { exitFullSreen, isFullScreenEnabled, isFullScreenSupported, requestFullScreen, } from '../../utils/full-screen';
/**
 * A button which toggles full screen mode for any
 * existing `dyte-meeting` component in the DOM.
 */
export class DyteFullscreenToggle {
  constructor() {
    /** Variant */
    this.variant = 'button';
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.fullScreenActive = false;
    this.isFullScreenSupported = true;
    this.toggleFullScreen = () => {
      const fullScreenElement = document.querySelector('dyte-meeting');
      if (!fullScreenElement)
        return;
      if (!this.fullScreenActive) {
        requestFullScreen(fullScreenElement);
        this.fullScreenActive = true;
      }
      else {
        exitFullSreen();
        this.fullScreenActive = false;
      }
    };
  }
  connectedCallback() {
    this.isFullScreenSupported = isFullScreenSupported();
    this.handleFullScreenChange = () => {
      this.fullScreenActive = isFullScreenEnabled();
    };
    window.addEventListener('webkitfullscreenchange', this.handleFullScreenChange);
    window.addEventListener('fullscreenchange', this.handleFullScreenChange);
  }
  disconnectedCallback() {
    window.removeEventListener('webkitfullscreenchange', this.handleFullScreenChange);
    window.removeEventListener('fullscreenchange', this.handleFullScreenChange);
  }
  render() {
    if (!this.isFullScreenSupported) {
      return null;
    }
    return (h(Host, { title: this.t('Fullscreen') },
      h("dyte-controlbar-button", { size: this.size, iconPack: this.iconPack, onClick: this.toggleFullScreen, icon: this.fullScreenActive
          ? this.iconPack.full_screen_minimize
          : this.iconPack.full_screen_maximize, label: this.t('Fullscreen'), variant: this.variant })));
  }
  static get is() { return "dyte-fullscreen-toggle"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-fullscreen-toggle.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-fullscreen-toggle.css"]
  }; }
  static get properties() { return {
    "variant": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "ControlBarVariant",
        "resolved": "\"button\" | \"horizontal\"",
        "references": {
          "ControlBarVariant": {
            "location": "import",
            "path": "../dyte-controlbar-button/dyte-controlbar-button"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Variant"
      },
      "attribute": "variant",
      "reflect": true,
      "defaultValue": "'button'"
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Size",
        "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\"",
        "references": {
          "Size": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Size"
      },
      "attribute": "size",
      "reflect": true
    },
    "iconPack": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IconPack",
        "resolved": "{ people: string; chat: string; poll: string; participants: string; rocket: string; call_end: string; share: string; mic_on: string; mic_off: string; video_on: string; video_off: string; share_screen_start: string; share_screen_stop: string; share_screen_person: string; clock: string; dismiss: string; send: string; search: string; more_vertical: string; chevron_down: string; chevron_up: string; chevron_left: string; chevron_right: string; settings: string; wifi: string; speaker: string; download: string; full_screen_maximize: string; full_screen_minimize: string; copy: string; attach: string; image: string; emoji_multiple: string; vertical_scroll: string; vertical_scroll_disabled: string; image_off: string; disconnected: string; wand: string; recording: string; subtract: string; stop_recording: string; warning: string; pin: string; pin_off: string; spinner: string; }",
        "references": {
          "IconPack": {
            "location": "import",
            "path": "../../lib/icons"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Icon pack"
      },
      "defaultValue": "defaultIconPack"
    },
    "t": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "resolved": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Language"
      },
      "defaultValue": "useLanguage()"
    }
  }; }
  static get states() { return {
    "fullScreenActive": {},
    "isFullScreenSupported": {}
  }; }
}
