import { Size, States } from '../../types/props';
import { Meeting } from '../../types/dyte-client';
import { Language } from '../../lib/lang';
import { IconPack } from '../../lib/icons';
import { UIConfig } from '../../types/ui-config';
export declare type MeetingMode = 'fixed' | 'fill';
/**
 * A single component which renders an entire meeting UI.
 *
 * It loads your preset and renders the UI based on it.
 * With this component, you don't have to handle all the states,
 * dialogs and other smaller bits of managing the application.
 */
export declare class DyteMeeting {
  private resizeObserver;
  private roomJoinedListener;
  private roomLeftListener;
  private mediaPermissionErrorListener;
  host: HTMLDyteMeetingElement;
  /** Whether to load config from preset */
  loadConfigFromPreset: boolean;
  /** Whether to apply the design system on the document root from config */
  applyDesignSystem: boolean;
  /** Fill type */
  mode: MeetingMode;
  /** Meeting object */
  meeting: Meeting;
  /** Where to show setup screen or not */
  showSetupScreen: boolean;
  /** Language */
  language: Language;
  /** UI Config */
  config: UIConfig;
  /** Icon Pack URL */
  iconPackUrl: string;
  /** Size */
  size: Size;
  states: States;
  iconPack: IconPack;
  t: import("../../index").DyteI18n;
  connectedCallback(): void;
  disconnectedCallback(): void;
  meetingChanged(meeting: Meeting): void;
  iconPackUrlChanged(url: string): Promise<void>;
  languageChanged(lang: Language): Promise<void>;
  listenState(e: CustomEvent<States>): void;
  private initializePreferences;
  private handleResize;
  private setStates;
  render(): any;
}
